Enum CommandArgumentError
#[non_exhaustive]pub enum CommandArgumentError {
Show 13 variants
TypeMismatch,
InvalidBcsBytes,
InvalidUsageOfPureArgument,
InvalidArgumentToPrivateEntryFunction,
IndexOutOfBounds {
index: u16,
},
SecondaryIndexOutOfBounds {
result: u16,
subresult: u16,
},
InvalidResultArity {
result: u16,
},
InvalidGasCoinUsage,
InvalidValueUsage,
InvalidObjectByValue,
InvalidObjectByMutRef,
SharedObjectOperationNotAllowed,
InvalidArgumentArity,
}Expand description
An error with an argument to a command
BCS
The BCS serialized form for this type is defined by the following ABNF:
command-argument-error = type-mismatch
=/ invalid-bcs-bytes
=/ invalid-usage-of-pure-argument
=/ invalid-argument-to-private-entry-function
=/ index-out-of-bounds
=/ secondary-index-out-of-bound
=/ invalid-result-arity
=/ invalid-gas-coin-usage
=/ invalid-value-usage
=/ invalid-object-by-value
=/ invalid-object-by-mut-ref
=/ shared-object-operation-not-allowed
type-mismatch = %d00
invalid-bcs-bytes = %d01
invalid-usage-of-pure-argument = %d02
invalid-argument-to-private-entry-function = %d03
index-out-of-bounds = %d04 u16
secondary-index-out-of-bound = %d05 u16 u16
invalid-result-arity = %d06 u16
invalid-gas-coin-usage = %d07
invalid-value-usage = %d08
invalid-object-by-value = %d09
invalid-object-by-mut-ref = %d10
shared-object-operation-not-allowed = %d11Variants (Non-exhaustive)
This enum is marked as non-exhaustive
TypeMismatch
The type of the value does not match the expected type
InvalidBcsBytes
The argument cannot be deserialized into a value of the specified type
InvalidUsageOfPureArgument
The argument cannot be instantiated from raw bytes
InvalidArgumentToPrivateEntryFunction
Invalid argument to private entry function. Private entry functions cannot take arguments from other Move functions.
IndexOutOfBounds
Out of bounds access to input or results
SecondaryIndexOutOfBounds
Out of bounds access to subresult
InvalidResultArity
Invalid usage of result. Expected a single result but found either no return value or multiple.
InvalidGasCoinUsage
Invalid usage of Gas coin. The Gas coin can only be used by-value with a TransferObjects command.
InvalidValueUsage
Invalid usage of move value.
InvalidObjectByValue
Immutable objects cannot be passed by-value.
InvalidObjectByMutRef
Immutable objects cannot be passed by mutable reference, &mut.
Shared object operations such a wrapping, freezing, or converting to owned are not allowed.
InvalidArgumentArity
Invalid argument arity. Expected a single argument but found a result that expanded to multiple arguments.
Implementations
impl CommandArgumentError
impl CommandArgumentError
pub fn is_type_mismatch(&self) -> bool
pub fn is_type_mismatch(&self) -> bool
Checks if this is a type_mismatch variant.
pub fn is_invalid_bcs_bytes(&self) -> bool
pub fn is_invalid_bcs_bytes(&self) -> bool
Checks if this is a invalid_bcs_bytes variant.
pub fn is_invalid_usage_of_pure_argument(&self) -> bool
pub fn is_invalid_usage_of_pure_argument(&self) -> bool
Checks if this is a invalid_usage_of_pure_argument variant.
pub fn is_invalid_argument_to_private_entry_function(&self) -> bool
pub fn is_invalid_argument_to_private_entry_function(&self) -> bool
Checks if this is a invalid_argument_to_private_entry_function variant.
pub fn is_index_out_of_bounds(&self) -> bool
pub fn is_index_out_of_bounds(&self) -> bool
Checks if this is a index_out_of_bounds variant.
pub fn is_secondary_index_out_of_bounds(&self) -> bool
pub fn is_secondary_index_out_of_bounds(&self) -> bool
Checks if this is a secondary_index_out_of_bounds variant.
pub fn is_invalid_result_arity(&self) -> bool
pub fn is_invalid_result_arity(&self) -> bool
Checks if this is a invalid_result_arity variant.
pub fn is_invalid_gas_coin_usage(&self) -> bool
pub fn is_invalid_gas_coin_usage(&self) -> bool
Checks if this is a invalid_gas_coin_usage variant.
pub fn is_invalid_value_usage(&self) -> bool
pub fn is_invalid_value_usage(&self) -> bool
Checks if this is a invalid_value_usage variant.
pub fn is_invalid_object_by_value(&self) -> bool
pub fn is_invalid_object_by_value(&self) -> bool
Checks if this is a invalid_object_by_value variant.
pub fn is_invalid_object_by_mut_ref(&self) -> bool
pub fn is_invalid_object_by_mut_ref(&self) -> bool
Checks if this is a invalid_object_by_mut_ref variant.
Checks if this is a shared_object_operation_not_allowed variant.