Enum ExecutionStatus
#[non_exhaustive]pub enum ExecutionStatus {
Success,
Failure {
error: ExecutionError,
command: Option<u64>,
},
}Expand description
The status of an executed Transaction
BCS
The BCS serialized form for this type is defined by the following ABNF:
execution-status = success / failure
success = %d00
failure = %d01 execution-error (option u64)Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Success
The Transaction successfully executed.
Failure
The Transaction didn’t execute successfully.
Failed transactions are still committed to the blockchain but any intended effects are rolled back to prior to this transaction executing with the caveat that gas objects are still smashed and gas usage is still charged.
Fields

error: ExecutionErrorThe error encountered during execution.
Implementations
impl ExecutionStatus
impl ExecutionStatus
pub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Checks if this is a success variant.
pub fn is_failure(&self) -> bool
pub fn is_failure(&self) -> bool
Checks if this is a failure variant.
pub fn new_failure( error: ExecutionError, command: Option<u64>, ) -> ExecutionStatus
pub fn unwrap(&self)
pub fn unwrap_err(self) -> (ExecutionError, Option<u64>)
pub fn error(&self) -> Option<&ExecutionError>
pub fn error(&self) -> Option<&ExecutionError>
The error encountered during execution.
pub fn error_command(&self) -> Option<u64>
pub fn error_command(&self) -> Option<u64>
The command, if any, during which the error occurred.