Enum TypeArgumentError
#[non_exhaustive]pub enum TypeArgumentError {
TypeNotFound,
ConstraintNotSatisfied,
}Expand description
An error with a type argument
BCS
The BCS serialized form for this type is defined by the following ABNF:
type-argument-error = type-not-found / constraint-not-satisfied
type-not-found = %d00
constraint-not-satisfied = %d01Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TypeNotFound
A type was not found in the module specified
ConstraintNotSatisfied
A type provided did not match the specified constraint
Implementations
impl TypeArgumentError
impl TypeArgumentError
pub fn is_type_not_found(&self) -> bool
pub fn is_type_not_found(&self) -> bool
Checks if this is a type_not_found variant.
pub fn is_constraint_not_satisfied(&self) -> bool
pub fn is_constraint_not_satisfied(&self) -> bool
Checks if this is a constraint_not_satisfied variant.