Struct MoveLocation
pub struct MoveLocation {
pub package: ObjectId,
pub module: Identifier,
pub function: u16,
pub instruction: u16,
pub function_name: Option<Identifier>,
}Expand description
Location in move bytecode where an error occurred
BCS
The BCS serialized form for this type is defined by the following ABNF:
move-location = object-id identifier u16 u16 (option identifier)Fields
package: ObjectIdThe package id
module: IdentifierThe module name
function: u16The function index
instruction: u16Index into the code stream for a jump. The offset is relative to the beginning of the instruction stream.
function_name: Option<Identifier>The name of the function if available