Enum ExecutionFailureStatus
#[non_exhaustive]pub enum ExecutionFailureStatus {
Show 39 variants
InsufficientGas,
InvalidGasObject,
InvariantViolation,
FeatureNotYetSupported,
ObjectTooBig {
object_size: u64,
max_object_size: u64,
},
PackageTooBig {
object_size: u64,
max_object_size: u64,
},
CircularObjectOwnership {
object: ObjectId,
},
InsufficientCoinBalance,
CoinBalanceOverflow,
PublishErrorNonZeroAddress,
IotaMoveVerificationError,
MovePrimitiveRuntimeError {
location: Option<MoveLocation>,
},
MoveAbort {
location: MoveLocation,
code: u64,
},
VmVerificationOrDeserializationError,
VmInvariantViolation,
FunctionNotFound,
ArityMismatch,
TypeArityMismatch,
NonEntryFunctionInvoked,
CommandArgumentError {
argument: u16,
kind: CommandArgumentError,
},
TypeArgumentError {
type_argument: u16,
kind: TypeArgumentError,
},
UnusedValueWithoutDrop {
result: u16,
subresult: u16,
},
InvalidPublicFunctionReturnType {
index: u16,
},
InvalidTransferObject,
EffectsTooLarge {
current_size: u64,
max_size: u64,
},
PublishUpgradeMissingDependency,
PublishUpgradeDependencyDowngrade,
PackageUpgradeError {
kind: PackageUpgradeError,
},
WrittenObjectsTooLarge {
object_size: u64,
max_object_size: u64,
},
CertificateDenied,
IotaMoveVerificationTimeout,
SharedObjectOperationNotAllowed,
InputObjectDeleted,
ExecutionCancelledDueToSharedObjectCongestion {
congested_objects: Vec<ObjectId>,
},
AddressDeniedForCoin {
address: Address,
coin_type: String,
},
CoinTypeGlobalPause {
coin_type: String,
},
ExecutionCancelledDueToRandomnessUnavailable,
ExecutionCancelledDueToSharedObjectCongestionV2 {
congested_objects: Vec<ObjectId>,
suggested_gas_price: u64,
},
InvalidLinkage,
}Expand description
An error that can occur during the execution of a transaction
BCS
The BCS serialized form for this type is defined by the following ABNF:
execution-error = insufficient-gas
=/ invalid-gas-object
=/ invariant-violation
=/ feature-not-yet-supported
=/ object-too-big
=/ package-too-big
=/ circular-object-ownership
=/ insufficient-coin-balance
=/ coin-balance-overflow
=/ publish-error-non-zero-address
=/ iota-move-verification-error
=/ move-primitive-runtime-error
=/ move-abort
=/ vm-verification-or-deserialization-error
=/ vm-invariant-violation
=/ function-not-found
=/ arity-mismatch
=/ type-arity-mismatch
=/ non-entry-function-invoked
=/ command-argument-error
=/ type-argument-error
=/ unused-value-without-drop
=/ invalid-public-function-return-type
=/ invalid-transfer-object
=/ effects-too-large
=/ publish-upgrade-missing-dependency
=/ publish-upgrade-dependency-downgrade
=/ package-upgrade-error
=/ written-objects-too-large
=/ certificate-denied
=/ iota-move-verification-timeout
=/ shared-object-operation-not-allowed
=/ input-object-deleted
=/ execution-cancelled-due-to-shared-object-congestion
=/ address-denied-for-coin
=/ coin-type-global-pause
=/ execution-cancelled-due-to-randomness-unavailable
=/ execution-cancelled-due-to-shared-object-congestion-v2
=/ invalid-linkage
insufficient-gas = %d00
invalid-gas-object = %d01
invariant-violation = %d02
feature-not-yet-supported = %d03
object-too-big = %d04 u64 u64
package-too-big = %d05 u64 u64
circular-object-ownership = %d06 object-id
insufficient-coin-balance = %d07
coin-balance-overflow = %d08
publish-error-non-zero-address = %d09
iota-move-verification-error = %d10
move-primitive-runtime-error = %d11 (option move-location)
move-abort = %d12 move-location u64
vm-verification-or-deserialization-error = %d13
vm-invariant-violation = %d14
function-not-found = %d15
arity-mismatch = %d16
type-arity-mismatch = %d17
non-entry-function-invoked = %d18
command-argument-error = %d19 u16 command-argument-error
type-argument-error = %d20 u16 type-argument-error
unused-value-without-drop = %d21 u16 u16
invalid-public-function-return-type = %d22 u16
invalid-transfer-object = %d23
effects-too-large = %d24 u64 u64
publish-upgrade-missing-dependency = %d25
publish-upgrade-dependency-downgrade = %d26
package-upgrade-error = %d27 package-upgrade-error
written-objects-too-large = %d28 u64 u64
certificate-denied = %d29
iota-move-verification-timeout = %d30
shared-object-operation-not-allowed = %d31
input-object-deleted = %d32
execution-cancelled-due-to-shared-object-congestion = %d33 (vector object-id)
address-denied-for-coin = %d34 address string
coin-type-global-pause = %d35 string
execution-cancelled-due-to-randomness-unavailable = %d36
execution-cancelled-due-to-shared-object-congestion-v2 = %d37 (vector object-id) u64
invalid-linkage = %d38Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InsufficientGas
Insufficient Gas
InvalidGasObject
Invalid Gas Object.
InvariantViolation
Invariant Violation
FeatureNotYetSupported
Attempted to use feature that is not supported yet
ObjectTooBig
Move object is larger than the maximum allowed size
PackageTooBig
Package is larger than the maximum allowed size
CircularObjectOwnership
Circular Object Ownership
InsufficientCoinBalance
Insufficient coin balance for requested operation
CoinBalanceOverflow
Coin balance overflowed an u64
PublishErrorNonZeroAddress
Publish Error, Non-zero Address. The modules in the package must have their self-addresses set to zero.
IotaMoveVerificationError
IOTA Move Bytecode Verification Error.
MovePrimitiveRuntimeError
Error from a non-abort instruction. Possible causes: Arithmetic error, stack overflow, max value depth, etc.“
Fields
location: Option<MoveLocation>MoveAbort
Move runtime abort
VmVerificationOrDeserializationError
Bytecode verification error.
VmInvariantViolation
MoveVm invariant violation
FunctionNotFound
Function not found
ArityMismatch
Arity mismatch for Move function. The number of arguments does not match the number of parameters
TypeArityMismatch
Type arity mismatch for Move function. Mismatch between the number of actual versus expected type arguments.
NonEntryFunctionInvoked
Non Entry Function Invoked. Move Call must start with an entry function.
CommandArgumentError
Invalid command argument
TypeArgumentError
Type argument error
UnusedValueWithoutDrop
Unused result without the drop ability.
InvalidPublicFunctionReturnType
Invalid public Move function signature. Unsupported return type for return value
InvalidTransferObject
Invalid Transfer Object, object does not have public transfer.
EffectsTooLarge
Effects from the transaction are too large
PublishUpgradeMissingDependency
Publish or Upgrade is missing dependency
PublishUpgradeDependencyDowngrade
Publish or Upgrade dependency downgrade.
Indirect (transitive) dependency of published or upgraded package has been assigned an on-chain version that is less than the version required by one of the package’s transitive dependencies.
PackageUpgradeError
Invalid package upgrade
Fields
kind: PackageUpgradeErrorWrittenObjectsTooLarge
Indicates the transaction tried to write objects too large to storage
CertificateDenied
Certificate is on the deny list
IotaMoveVerificationTimeout
IOTA Move Bytecode verification timed out.
The requested shared object operation is not allowed
InputObjectDeleted
Requested shared object has been deleted
Certificate is cancelled due to congestion on shared objects
AddressDeniedForCoin
Address is denied for this coin type
CoinTypeGlobalPause
Coin type is globally paused for use
Certificate is cancelled because randomness could not be generated this epoch
Certificate is cancelled due to congestion on shared objects; suggested gas price can be used to give this certificate more priority.
InvalidLinkage
A valid linkage was unable to be determined for the transaction or one of its commands.
Implementations
impl ExecutionError
impl ExecutionError
pub fn is_insufficient_gas(&self) -> bool
pub fn is_insufficient_gas(&self) -> bool
Checks if this is a insufficient_gas variant.
pub fn is_invalid_gas_object(&self) -> bool
pub fn is_invalid_gas_object(&self) -> bool
Checks if this is a invalid_gas_object variant.
pub fn is_invariant_violation(&self) -> bool
pub fn is_invariant_violation(&self) -> bool
Checks if this is a invariant_violation variant.
pub fn is_feature_not_yet_supported(&self) -> bool
pub fn is_feature_not_yet_supported(&self) -> bool
Checks if this is a feature_not_yet_supported variant.
pub fn is_object_too_big(&self) -> bool
pub fn is_object_too_big(&self) -> bool
Checks if this is a object_too_big variant.
pub fn is_package_too_big(&self) -> bool
pub fn is_package_too_big(&self) -> bool
Checks if this is a package_too_big variant.
pub fn is_circular_object_ownership(&self) -> bool
pub fn is_circular_object_ownership(&self) -> bool
Checks if this is a circular_object_ownership variant.
pub fn is_insufficient_coin_balance(&self) -> bool
pub fn is_insufficient_coin_balance(&self) -> bool
Checks if this is a insufficient_coin_balance variant.
pub fn is_coin_balance_overflow(&self) -> bool
pub fn is_coin_balance_overflow(&self) -> bool
Checks if this is a coin_balance_overflow variant.
pub fn is_publish_error_non_zero_address(&self) -> bool
pub fn is_publish_error_non_zero_address(&self) -> bool
Checks if this is a publish_error_non_zero_address variant.
pub fn is_iota_move_verification_error(&self) -> bool
pub fn is_iota_move_verification_error(&self) -> bool
Checks if this is a iota_move_verification_error variant.
pub fn is_move_primitive_runtime_error(&self) -> bool
pub fn is_move_primitive_runtime_error(&self) -> bool
Checks if this is a move_primitive_runtime_error variant.
pub fn is_move_abort(&self) -> bool
pub fn is_move_abort(&self) -> bool
Checks if this is a move_abort variant.
pub fn is_vm_verification_or_deserialization_error(&self) -> bool
pub fn is_vm_verification_or_deserialization_error(&self) -> bool
Checks if this is a vm_verification_or_deserialization_error variant.
pub fn is_vm_invariant_violation(&self) -> bool
pub fn is_vm_invariant_violation(&self) -> bool
Checks if this is a vm_invariant_violation variant.
pub fn is_function_not_found(&self) -> bool
pub fn is_function_not_found(&self) -> bool
Checks if this is a function_not_found variant.
pub fn is_arity_mismatch(&self) -> bool
pub fn is_arity_mismatch(&self) -> bool
Checks if this is a arity_mismatch variant.
pub fn is_type_arity_mismatch(&self) -> bool
pub fn is_type_arity_mismatch(&self) -> bool
Checks if this is a type_arity_mismatch variant.
pub fn is_non_entry_function_invoked(&self) -> bool
pub fn is_non_entry_function_invoked(&self) -> bool
Checks if this is a non_entry_function_invoked variant.
pub fn is_command_argument_error(&self) -> bool
pub fn is_command_argument_error(&self) -> bool
Checks if this is a command_argument_error variant.
pub fn is_type_argument_error(&self) -> bool
pub fn is_type_argument_error(&self) -> bool
Checks if this is a type_argument_error variant.
pub fn is_unused_value_without_drop(&self) -> bool
pub fn is_unused_value_without_drop(&self) -> bool
Checks if this is a unused_value_without_drop variant.
pub fn is_invalid_public_function_return_type(&self) -> bool
pub fn is_invalid_public_function_return_type(&self) -> bool
Checks if this is a invalid_public_function_return_type variant.
pub fn is_invalid_transfer_object(&self) -> bool
pub fn is_invalid_transfer_object(&self) -> bool
Checks if this is a invalid_transfer_object variant.
pub fn is_effects_too_large(&self) -> bool
pub fn is_effects_too_large(&self) -> bool
Checks if this is a effects_too_large variant.
pub fn is_publish_upgrade_missing_dependency(&self) -> bool
pub fn is_publish_upgrade_missing_dependency(&self) -> bool
Checks if this is a publish_upgrade_missing_dependency variant.
pub fn is_publish_upgrade_dependency_downgrade(&self) -> bool
pub fn is_publish_upgrade_dependency_downgrade(&self) -> bool
Checks if this is a publish_upgrade_dependency_downgrade variant.
pub fn is_package_upgrade_error(&self) -> bool
pub fn is_package_upgrade_error(&self) -> bool
Checks if this is a package_upgrade_error variant.
pub fn is_written_objects_too_large(&self) -> bool
pub fn is_written_objects_too_large(&self) -> bool
Checks if this is a written_objects_too_large variant.
pub fn is_certificate_denied(&self) -> bool
pub fn is_certificate_denied(&self) -> bool
Checks if this is a certificate_denied variant.
pub fn is_iota_move_verification_timeout(&self) -> bool
pub fn is_iota_move_verification_timeout(&self) -> bool
Checks if this is a iota_move_verification_timeout variant.
Checks if this is a shared_object_operation_not_allowed variant.
pub fn is_input_object_deleted(&self) -> bool
pub fn is_input_object_deleted(&self) -> bool
Checks if this is a input_object_deleted variant.
Checks if this is a execution_cancelled_due_to_shared_object_congestion variant.
pub fn is_address_denied_for_coin(&self) -> bool
pub fn is_address_denied_for_coin(&self) -> bool
Checks if this is a address_denied_for_coin variant.
pub fn is_coin_type_global_pause(&self) -> bool
pub fn is_coin_type_global_pause(&self) -> bool
Checks if this is a coin_type_global_pause variant.
Checks if this is a execution_cancelled_due_to_randomness_unavailable variant.
Checks if this is a execution_cancelled_due_to_shared_object_congestion_v2 variant.
pub fn is_invalid_linkage(&self) -> bool
pub fn is_invalid_linkage(&self) -> bool
Checks if this is a invalid_linkage variant.
pub fn command_argument_error( kind: CommandArgumentError, argument: u16, ) -> ExecutionError